# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/common/metrics.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/common/metrics.proto',
  package='google.ads.googleads.v0.common',
  syntax='proto3',
  serialized_pb=_b('\n2google/ads/googleads_v0/proto/common/metrics.proto\x12\x1egoogle.ads.googleads.v0.common\x1a\x1egoogle/protobuf/wrappers.proto\"\xbc\x1a\n\x07Metrics\x12L\n&all_conversions_from_interactions_rate\x18\x41 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12;\n\x15\x61ll_conversions_value\x18\x42 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x35\n\x0f\x61ll_conversions\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x44\n\x1e\x61ll_conversions_value_per_cost\x18> \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12]\n7all_conversions_from_interactions_value_per_interaction\x18\x43 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x32\n\x0c\x61verage_cost\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x31\n\x0b\x61verage_cpc\x18\t \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x31\n\x0b\x61verage_cpm\x18\n \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x31\n\x0b\x61verage_cpv\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x36\n\x10\x61verage_position\x18\r \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x33\n\rbenchmark_ctr\x18M \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x31\n\x0b\x62ounce_rate\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12+\n\x06\x63licks\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12J\n$content_budget_lost_impression_share\x18\x14 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12>\n\x18\x63ontent_impression_share\x18\x15 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12P\n*conversion_last_received_request_date_time\x18I \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x45\n\x1f\x63onversion_last_conversion_date\x18J \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12H\n\"content_rank_lost_impression_share\x18\x16 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12H\n\"conversions_from_interactions_rate\x18\x45 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x37\n\x11\x63onversions_value\x18\x46 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12@\n\x1a\x63onversions_value_per_cost\x18G \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12Y\n3conversions_from_interactions_value_per_interaction\x18H \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x31\n\x0b\x63onversions\x18\x19 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x30\n\x0b\x63ost_micros\x18\x1a \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x18\x63ost_per_all_conversions\x18\x44 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x39\n\x13\x63ost_per_conversion\x18\x1c \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12>\n\x18\x63ross_device_conversions\x18\x1d \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12)\n\x03\x63tr\x18\x1e \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x35\n\x0f\x65ngagement_rate\x18\x1f \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x30\n\x0b\x65ngagements\x18  \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x45\n\x1fhotel_average_lead_value_micros\x18K \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x30\n\x0bimpressions\x18% \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x10interaction_rate\x18& \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x31\n\x0cinteractions\x18\' \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x12invalid_click_rate\x18( \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x33\n\x0einvalid_clicks\x18) \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x14percent_new_visitors\x18* \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x30\n\x0bphone_calls\x18+ \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11phone_impressions\x18, \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x12phone_through_rate\x18- \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x32\n\x0crelative_ctr\x18. \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12J\n$search_absolute_top_impression_share\x18N \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12I\n#search_budget_lost_impression_share\x18/ \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12I\n#search_exact_match_impression_share\x18\x31 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12=\n\x17search_impression_share\x18\x32 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12G\n!search_rank_lost_impression_share\x18\x33 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12?\n\x19value_per_all_conversions\x18\x34 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12:\n\x14value_per_conversion\x18\x35 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12=\n\x17video_quartile_100_rate\x18\x36 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12<\n\x16video_quartile_25_rate\x18\x37 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12<\n\x16video_quartile_50_rate\x18\x38 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12<\n\x16video_quartile_75_rate\x18\x39 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x35\n\x0fvideo_view_rate\x18: \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x30\n\x0bvideo_views\x18; \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12=\n\x18view_through_conversions\x18< \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\xc2\x01\n\"com.google.ads.googleads.v0.commonB\x0cMetricsProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V0.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V0\\Commonb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_METRICS = _descriptor.Descriptor(
  name='Metrics',
  full_name='google.ads.googleads.v0.common.Metrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='all_conversions_from_interactions_rate', full_name='google.ads.googleads.v0.common.Metrics.all_conversions_from_interactions_rate', index=0,
      number=65, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_conversions_value', full_name='google.ads.googleads.v0.common.Metrics.all_conversions_value', index=1,
      number=66, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_conversions', full_name='google.ads.googleads.v0.common.Metrics.all_conversions', index=2,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_conversions_value_per_cost', full_name='google.ads.googleads.v0.common.Metrics.all_conversions_value_per_cost', index=3,
      number=62, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_conversions_from_interactions_value_per_interaction', full_name='google.ads.googleads.v0.common.Metrics.all_conversions_from_interactions_value_per_interaction', index=4,
      number=67, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_cost', full_name='google.ads.googleads.v0.common.Metrics.average_cost', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_cpc', full_name='google.ads.googleads.v0.common.Metrics.average_cpc', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_cpm', full_name='google.ads.googleads.v0.common.Metrics.average_cpm', index=7,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_cpv', full_name='google.ads.googleads.v0.common.Metrics.average_cpv', index=8,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_position', full_name='google.ads.googleads.v0.common.Metrics.average_position', index=9,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='benchmark_ctr', full_name='google.ads.googleads.v0.common.Metrics.benchmark_ctr', index=10,
      number=77, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bounce_rate', full_name='google.ads.googleads.v0.common.Metrics.bounce_rate', index=11,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clicks', full_name='google.ads.googleads.v0.common.Metrics.clicks', index=12,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_budget_lost_impression_share', full_name='google.ads.googleads.v0.common.Metrics.content_budget_lost_impression_share', index=13,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_impression_share', full_name='google.ads.googleads.v0.common.Metrics.content_impression_share', index=14,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_last_received_request_date_time', full_name='google.ads.googleads.v0.common.Metrics.conversion_last_received_request_date_time', index=15,
      number=73, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_last_conversion_date', full_name='google.ads.googleads.v0.common.Metrics.conversion_last_conversion_date', index=16,
      number=74, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_rank_lost_impression_share', full_name='google.ads.googleads.v0.common.Metrics.content_rank_lost_impression_share', index=17,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversions_from_interactions_rate', full_name='google.ads.googleads.v0.common.Metrics.conversions_from_interactions_rate', index=18,
      number=69, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversions_value', full_name='google.ads.googleads.v0.common.Metrics.conversions_value', index=19,
      number=70, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversions_value_per_cost', full_name='google.ads.googleads.v0.common.Metrics.conversions_value_per_cost', index=20,
      number=71, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversions_from_interactions_value_per_interaction', full_name='google.ads.googleads.v0.common.Metrics.conversions_from_interactions_value_per_interaction', index=21,
      number=72, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversions', full_name='google.ads.googleads.v0.common.Metrics.conversions', index=22,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost_micros', full_name='google.ads.googleads.v0.common.Metrics.cost_micros', index=23,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost_per_all_conversions', full_name='google.ads.googleads.v0.common.Metrics.cost_per_all_conversions', index=24,
      number=68, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost_per_conversion', full_name='google.ads.googleads.v0.common.Metrics.cost_per_conversion', index=25,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cross_device_conversions', full_name='google.ads.googleads.v0.common.Metrics.cross_device_conversions', index=26,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ctr', full_name='google.ads.googleads.v0.common.Metrics.ctr', index=27,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='engagement_rate', full_name='google.ads.googleads.v0.common.Metrics.engagement_rate', index=28,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='engagements', full_name='google.ads.googleads.v0.common.Metrics.engagements', index=29,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_average_lead_value_micros', full_name='google.ads.googleads.v0.common.Metrics.hotel_average_lead_value_micros', index=30,
      number=75, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='impressions', full_name='google.ads.googleads.v0.common.Metrics.impressions', index=31,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interaction_rate', full_name='google.ads.googleads.v0.common.Metrics.interaction_rate', index=32,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interactions', full_name='google.ads.googleads.v0.common.Metrics.interactions', index=33,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invalid_click_rate', full_name='google.ads.googleads.v0.common.Metrics.invalid_click_rate', index=34,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invalid_clicks', full_name='google.ads.googleads.v0.common.Metrics.invalid_clicks', index=35,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='percent_new_visitors', full_name='google.ads.googleads.v0.common.Metrics.percent_new_visitors', index=36,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phone_calls', full_name='google.ads.googleads.v0.common.Metrics.phone_calls', index=37,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phone_impressions', full_name='google.ads.googleads.v0.common.Metrics.phone_impressions', index=38,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phone_through_rate', full_name='google.ads.googleads.v0.common.Metrics.phone_through_rate', index=39,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relative_ctr', full_name='google.ads.googleads.v0.common.Metrics.relative_ctr', index=40,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_absolute_top_impression_share', full_name='google.ads.googleads.v0.common.Metrics.search_absolute_top_impression_share', index=41,
      number=78, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_budget_lost_impression_share', full_name='google.ads.googleads.v0.common.Metrics.search_budget_lost_impression_share', index=42,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_exact_match_impression_share', full_name='google.ads.googleads.v0.common.Metrics.search_exact_match_impression_share', index=43,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_impression_share', full_name='google.ads.googleads.v0.common.Metrics.search_impression_share', index=44,
      number=50, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_rank_lost_impression_share', full_name='google.ads.googleads.v0.common.Metrics.search_rank_lost_impression_share', index=45,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_per_all_conversions', full_name='google.ads.googleads.v0.common.Metrics.value_per_all_conversions', index=46,
      number=52, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_per_conversion', full_name='google.ads.googleads.v0.common.Metrics.value_per_conversion', index=47,
      number=53, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='video_quartile_100_rate', full_name='google.ads.googleads.v0.common.Metrics.video_quartile_100_rate', index=48,
      number=54, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='video_quartile_25_rate', full_name='google.ads.googleads.v0.common.Metrics.video_quartile_25_rate', index=49,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='video_quartile_50_rate', full_name='google.ads.googleads.v0.common.Metrics.video_quartile_50_rate', index=50,
      number=56, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='video_quartile_75_rate', full_name='google.ads.googleads.v0.common.Metrics.video_quartile_75_rate', index=51,
      number=57, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='video_view_rate', full_name='google.ads.googleads.v0.common.Metrics.video_view_rate', index=52,
      number=58, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='video_views', full_name='google.ads.googleads.v0.common.Metrics.video_views', index=53,
      number=59, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view_through_conversions', full_name='google.ads.googleads.v0.common.Metrics.view_through_conversions', index=54,
      number=60, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=119,
  serialized_end=3507,
)

_METRICS.fields_by_name['all_conversions_from_interactions_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['all_conversions_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['all_conversions'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['all_conversions_value_per_cost'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['all_conversions_from_interactions_value_per_interaction'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['average_cost'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['average_cpc'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['average_cpm'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['average_cpv'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['average_position'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['benchmark_ctr'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['bounce_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['clicks'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['content_budget_lost_impression_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['content_impression_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['conversion_last_received_request_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_METRICS.fields_by_name['conversion_last_conversion_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_METRICS.fields_by_name['content_rank_lost_impression_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['conversions_from_interactions_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['conversions_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['conversions_value_per_cost'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['conversions_from_interactions_value_per_interaction'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['conversions'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['cost_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['cost_per_all_conversions'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['cost_per_conversion'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['cross_device_conversions'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['ctr'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['engagement_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['engagements'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['hotel_average_lead_value_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['impressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['interaction_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['interactions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['invalid_click_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['invalid_clicks'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['percent_new_visitors'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['phone_calls'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['phone_impressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['phone_through_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['relative_ctr'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['search_absolute_top_impression_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['search_budget_lost_impression_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['search_exact_match_impression_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['search_impression_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['search_rank_lost_impression_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['value_per_all_conversions'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['value_per_conversion'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['video_quartile_100_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['video_quartile_25_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['video_quartile_50_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['video_quartile_75_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['video_view_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['video_views'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['view_through_conversions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
DESCRIPTOR.message_types_by_name['Metrics'] = _METRICS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Metrics = _reflection.GeneratedProtocolMessageType('Metrics', (_message.Message,), dict(
  DESCRIPTOR = _METRICS,
  __module__ = 'google.ads.google_ads.v0.proto.common.metrics_pb2'
  ,
  __doc__ = """Metrics data.
  
  
  Attributes:
      all_conversions_from_interactions_rate:
          All conversions from interactions (as oppose to view through
          conversions) divided by the number of ad interactions.
      all_conversions_value:
          The total value of all conversions.
      all_conversions:
          The total number of conversions. This includes "Conversions"
          plus conversions that have their "Include in Conversions"
          setting unchecked.
      all_conversions_value_per_cost:
          The value of all conversions divided by the total cost of ad
          interactions (such as clicks for text ads or views for video
          ads).
      all_conversions_from_interactions_value_per_interaction:
          The value of all conversions from interactions divided by the
          total number of interactions.
      average_cost:
          The average amount you pay per interaction. This amount is the
          total cost of your ads divided by the total number of
          interactions.
      average_cpc:
          The total cost of all clicks divided by the total number of
          clicks received.
      average_cpm:
          Average cost-per-thousand impressions (CPM).
      average_cpv:
          The average amount you pay each time someone views your ad.
          The average CPV is defined by the total cost of all ad views
          divided by the number of views.
      average_position:
          Your ad's position relative to those of other advertisers.
      benchmark_ctr:
          An indication on how other advertisers' Shopping ads for
          similar products are performing based on how often people who
          see their ad click on it.
      bounce_rate:
          Percentage of clicks where the user only visited a single page
          on your site. Imported from Google Analytics.
      clicks:
          The number of clicks.
      content_budget_lost_impression_share:
          The estimated percent of times that your ad was eligible to
          show on the Display Network but didn't because your budget was
          too low. Note: Content budget lost impression share is
          reported in the range of 0 to 0.9. Any value above 0.9 is
          reported as 0.9001.
      content_impression_share:
          The impressions you've received on the Display Network divided
          by the estimated number of impressions you were eligible to
          receive. Note: Content impression share is reported in the
          range of 0.1 to 1. Any value below 0.1 is reported as 0.0999.
      conversion_last_received_request_date_time:
          The last date/time a conversion tag for this conversion action
          successfully fired and was seen by Google Ads. This firing
          event may not have been the result of an attributable
          conversion (e.g. because the tag was fired from a browser that
          did not previously click an ad from an appropriate
          advertiser). The date/time is in the customer's time zone.
      conversion_last_conversion_date:
          The date of the most recent conversion for this conversion
          action. The date is in the customer's time zone.
      content_rank_lost_impression_share:
          The estimated percentage of impressions on the Display Network
          that your ads didn't receive due to poor Ad Rank. Note:
          Content rank lost impression share is reported in the range of
          0 to 0.9. Any value above 0.9 is reported as 0.9001.
      conversions_from_interactions_rate:
          Conversions from interactions divided by the number of ad
          interactions (such as clicks for text ads or views for video
          ads).
      conversions_value:
          The total value of conversions.
      conversions_value_per_cost:
          The value of conversions divided by the cost of ad
          interactions.
      conversions_from_interactions_value_per_interaction:
          The value of conversions from interactions divided by the
          number of ad interactions.
      conversions:
          The number of conversions. This only includes conversion
          actions which have "Include in Conversions" checked.
      cost_micros:
          The sum of your cost-per-click (CPC) and cost-per-thousand
          impressions (CPM) costs during this period.
      cost_per_all_conversions:
          The cost of ad interactions divided by all conversions.
      cost_per_conversion:
          The cost of ad interactions divided by conversions.
      cross_device_conversions:
          Conversions from when a customer clicks on a Google Ads ad on
          one device, then converts on a different device or browser.
          Cross-device conversions are already included in
          all\_conversions.
      ctr:
          The number of clicks your ad receives (Clicks) divided by the
          number of times your ad is shown (Impressions).
      engagement_rate:
          How often people engage with your ad after it's shown to them.
          This is the number of ad expansions divided by the number of
          times your ad is shown.
      engagements:
          The number of engagements. An engagement occurs when a viewer
          expands your Lightbox ad. Also, in the future, other ad types
          may support engagement metrics.
      hotel_average_lead_value_micros:
          Average lead value of hotel.
      impressions:
          Count of how often your ad has appeared on a search results
          page or website on the Google Network.
      interaction_rate:
          How often people interact with your ad after it is shown to
          them. This is the number of interactions divided by the number
          of times your ad is shown.
      interactions:
          The number of interactions. An interaction is the main user
          action associated with an ad format-clicks for text and
          shopping ads, views for video ads, and so on.
      invalid_click_rate:
          The percentage of clicks filtered out of your total number of
          clicks (filtered + non-filtered clicks) during the reporting
          period.
      invalid_clicks:
          Number of clicks Google considers illegitimate and doesn't
          charge you for.
      percent_new_visitors:
          Percentage of first-time sessions (from people who had never
          visited your site before). Imported from Google Analytics.
      phone_calls:
          Number of offline phone calls.
      phone_impressions:
          Number of offline phone impressions.
      phone_through_rate:
          Number of phone calls received (phone\_calls) divided by the
          number of times your phone number is shown
          (phone\_impressions).
      relative_ctr:
          Your clickthrough rate (Ctr) divided by the average
          clickthrough rate of all advertisers on the websites that show
          your ads. Measures how your ads perform on Display Network
          sites compared to other ads on the same sites.
      search_absolute_top_impression_share:
          The percentage of the customer's Shopping ad impressions that
          are shown in the most prominent Shopping position. See this
          Merchant Center article for details. Any value below 0.1 is
          reported as 0.0999.
      search_budget_lost_impression_share:
          The estimated percent of times that your ad was eligible to
          show on the Search Network but didn't because your budget was
          too low. Note: Search budget lost impression share is reported
          in the range of 0 to 0.9. Any value above 0.9 is reported as
          0.9001.
      search_exact_match_impression_share:
          The impressions you've received divided by the estimated
          number of impressions you were eligible to receive on the
          Search Network for search terms that matched your keywords
          exactly (or were close variants of your keyword), regardless
          of your keyword match types. Note: Search exact match
          impression share is reported in the range of 0.1 to 1. Any
          value below 0.1 is reported as 0.0999.
      search_impression_share:
          The impressions you've received on the Search Network divided
          by the estimated number of impressions you were eligible to
          receive. Note: Search impression share is reported in the
          range of 0.1 to 1. Any value below 0.1 is reported as 0.0999.
      search_rank_lost_impression_share:
          The estimated percentage of impressions on the Search Network
          that your ads didn't receive due to poor Ad Rank. Note: Search
          rank lost impression share is reported in the range of 0 to
          0.9. Any value above 0.9 is reported as 0.9001.
      value_per_all_conversions:
          The value of all conversions divided by the number of all
          conversions.
      value_per_conversion:
          The value of conversions divided by the number of conversions.
      video_quartile_100_rate:
          Percentage of impressions where the viewer watched all of your
          video.
      video_quartile_25_rate:
          Percentage of impressions where the viewer watched 25% of your
          video.
      video_quartile_50_rate:
          Percentage of impressions where the viewer watched 50% of your
          video.
      video_quartile_75_rate:
          Percentage of impressions where the viewer watched 75% of your
          video.
      video_view_rate:
          The number of views your TrueView video ad receives divided by
          its number of impressions, including thumbnail impressions for
          TrueView in-display ads.
      video_views:
          The number of times your video ads were viewed.
      view_through_conversions:
          The total number of view-through conversions. These happen
          when a customer sees an image or rich media ad, then later
          completes a conversion on your site without interacting with
          (e.g., clicking on) another ad.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.common.Metrics)
  ))
_sym_db.RegisterMessage(Metrics)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\"com.google.ads.googleads.v0.commonB\014MetricsProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V0.Common\312\002\036Google\\Ads\\GoogleAds\\V0\\Common'))
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v0.proto.services import keyword_plan_idea_service_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_keyword__plan__idea__service__pb2


class KeywordPlanIdeaServiceStub(object):
  """Service to generate keyword ideas.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GenerateKeywordIdeas = channel.unary_unary(
        '/google.ads.googleads.v0.services.KeywordPlanIdeaService/GenerateKeywordIdeas',
        request_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_keyword__plan__idea__service__pb2.GenerateKeywordIdeasRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_keyword__plan__idea__service__pb2.GenerateKeywordIdeaResponse.FromString,
        )


class KeywordPlanIdeaServiceServicer(object):
  """Service to generate keyword ideas.
  """

  def GenerateKeywordIdeas(self, request, context):
    """Returns a list of keyword ideas.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_KeywordPlanIdeaServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GenerateKeywordIdeas': grpc.unary_unary_rpc_method_handler(
          servicer.GenerateKeywordIdeas,
          request_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_keyword__plan__idea__service__pb2.GenerateKeywordIdeasRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_keyword__plan__idea__service__pb2.GenerateKeywordIdeaResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v0.services.KeywordPlanIdeaService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/resources/keyword_plan_negative_keyword.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.enums import keyword_match_type_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_keyword__match__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/resources/keyword_plan_negative_keyword.proto',
  package='google.ads.googleads.v0.resources',
  syntax='proto3',
  serialized_pb=_b('\nKgoogle/ads/googleads_v0/proto/resources/keyword_plan_negative_keyword.proto\x12!google.ads.googleads.v0.resources\x1a<google/ads/googleads_v0/proto/enums/keyword_match_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x9f\x02\n\x1aKeywordPlanNegativeKeyword\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12;\n\x15keyword_plan_campaign\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\'\n\x02id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04text\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12X\n\nmatch_type\x18\x05 \x01(\x0e\x32\x44.google.ads.googleads.v0.enums.KeywordMatchTypeEnum.KeywordMatchTypeB\xe4\x01\n%com.google.ads.googleads.v0.resourcesB\x1fKeywordPlanNegativeKeywordProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V0.Resources\xca\x02!Google\\Ads\\GoogleAds\\V0\\Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_keyword__match__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_KEYWORDPLANNEGATIVEKEYWORD = _descriptor.Descriptor(
  name='KeywordPlanNegativeKeyword',
  full_name='google.ads.googleads.v0.resources.KeywordPlanNegativeKeyword',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.resources.KeywordPlanNegativeKeyword.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_plan_campaign', full_name='google.ads.googleads.v0.resources.KeywordPlanNegativeKeyword.keyword_plan_campaign', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v0.resources.KeywordPlanNegativeKeyword.id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='google.ads.googleads.v0.resources.KeywordPlanNegativeKeyword.text', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_type', full_name='google.ads.googleads.v0.resources.KeywordPlanNegativeKeyword.match_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=496,
)

_KEYWORDPLANNEGATIVEKEYWORD.fields_by_name['keyword_plan_campaign'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORDPLANNEGATIVEKEYWORD.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_KEYWORDPLANNEGATIVEKEYWORD.fields_by_name['text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORDPLANNEGATIVEKEYWORD.fields_by_name['match_type'].enum_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_keyword__match__type__pb2._KEYWORDMATCHTYPEENUM_KEYWORDMATCHTYPE
DESCRIPTOR.message_types_by_name['KeywordPlanNegativeKeyword'] = _KEYWORDPLANNEGATIVEKEYWORD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeywordPlanNegativeKeyword = _reflection.GeneratedProtocolMessageType('KeywordPlanNegativeKeyword', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANNEGATIVEKEYWORD,
  __module__ = 'google.ads.google_ads.v0.proto.resources.keyword_plan_negative_keyword_pb2'
  ,
  __doc__ = """A Keyword Plan negative keyword.
  
  
  Attributes:
      resource_name:
          The resource name of the Keyword Plan negative keyword.
          KeywordPlanNegativeKeyword resource names have the form:  ``cu
          stomers/{customer_id}/keywordPlanNegativeKeywords/{kp_negative
          _keyword_id}``
      keyword_plan_campaign:
          The Keyword Plan campaign to which this negative keyword
          belongs.
      id:
          The ID of the Keyword Plan negative keyword.
      text:
          The keyword text.
      match_type:
          The keyword match type.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.resources.KeywordPlanNegativeKeyword)
  ))
_sym_db.RegisterMessage(KeywordPlanNegativeKeyword)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n%com.google.ads.googleads.v0.resourcesB\037KeywordPlanNegativeKeywordProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V0.Resources\312\002!Google\\Ads\\GoogleAds\\V0\\Resources'))
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v0.proto.resources import campaign_bid_modifier_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__bid__modifier__pb2
from google.ads.google_ads.v0.proto.services import campaign_bid_modifier_service_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__bid__modifier__service__pb2


class CampaignBidModifierServiceStub(object):
  """Service to manage campaign bid modifiers.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetCampaignBidModifier = channel.unary_unary(
        '/google.ads.googleads.v0.services.CampaignBidModifierService/GetCampaignBidModifier',
        request_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__bid__modifier__service__pb2.GetCampaignBidModifierRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__bid__modifier__pb2.CampaignBidModifier.FromString,
        )
    self.MutateCampaignBidModifiers = channel.unary_unary(
        '/google.ads.googleads.v0.services.CampaignBidModifierService/MutateCampaignBidModifiers',
        request_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__bid__modifier__service__pb2.MutateCampaignBidModifiersRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__bid__modifier__service__pb2.MutateCampaignBidModifiersResponse.FromString,
        )


class CampaignBidModifierServiceServicer(object):
  """Service to manage campaign bid modifiers.
  """

  def GetCampaignBidModifier(self, request, context):
    """Returns the requested campaign bid modifier in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateCampaignBidModifiers(self, request, context):
    """Creates, updates, or removes campaign bid modifiers.
    Operation statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CampaignBidModifierServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetCampaignBidModifier': grpc.unary_unary_rpc_method_handler(
          servicer.GetCampaignBidModifier,
          request_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__bid__modifier__service__pb2.GetCampaignBidModifierRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__bid__modifier__pb2.CampaignBidModifier.SerializeToString,
      ),
      'MutateCampaignBidModifiers': grpc.unary_unary_rpc_method_handler(
          servicer.MutateCampaignBidModifiers,
          request_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__bid__modifier__service__pb2.MutateCampaignBidModifiersRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__bid__modifier__service__pb2.MutateCampaignBidModifiersResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v0.services.CampaignBidModifierService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/enums/bidding_source.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/enums/bidding_source.proto',
  package='google.ads.googleads.v0.enums',
  syntax='proto3',
  serialized_pb=_b('\n8google/ads/googleads_v0/proto/enums/bidding_source.proto\x12\x1dgoogle.ads.googleads.v0.enums\"}\n\x11\x42iddingSourceEnum\"h\n\rBiddingSource\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0b\n\x07\x41\x44GROUP\x10\x02\x12\r\n\tCRITERION\x10\x03\x12\x1d\n\x19\x43\x41MPAIGN_BIDDING_STRATEGY\x10\x05\x42\xc3\x01\n!com.google.ads.googleads.v0.enumsB\x12\x42iddingSourceProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V0.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V0\\Enumsb\x06proto3')
)



_BIDDINGSOURCEENUM_BIDDINGSOURCE = _descriptor.EnumDescriptor(
  name='BiddingSource',
  full_name='google.ads.googleads.v0.enums.BiddingSourceEnum.BiddingSource',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADGROUP', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CRITERION', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CAMPAIGN_BIDDING_STRATEGY', index=4, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=112,
  serialized_end=216,
)
_sym_db.RegisterEnumDescriptor(_BIDDINGSOURCEENUM_BIDDINGSOURCE)


_BIDDINGSOURCEENUM = _descriptor.Descriptor(
  name='BiddingSourceEnum',
  full_name='google.ads.googleads.v0.enums.BiddingSourceEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BIDDINGSOURCEENUM_BIDDINGSOURCE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=91,
  serialized_end=216,
)

_BIDDINGSOURCEENUM_BIDDINGSOURCE.containing_type = _BIDDINGSOURCEENUM
DESCRIPTOR.message_types_by_name['BiddingSourceEnum'] = _BIDDINGSOURCEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BiddingSourceEnum = _reflection.GeneratedProtocolMessageType('BiddingSourceEnum', (_message.Message,), dict(
  DESCRIPTOR = _BIDDINGSOURCEENUM,
  __module__ = 'google.ads.google_ads.v0.proto.enums.bidding_source_pb2'
  ,
  __doc__ = """Container for enum describing possible bidding sources.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.enums.BiddingSourceEnum)
  ))
_sym_db.RegisterMessage(BiddingSourceEnum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n!com.google.ads.googleads.v0.enumsB\022BiddingSourceProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V0.Enums\312\002\035Google\\Ads\\GoogleAds\\V0\\Enums'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/common/user_lists.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.enums import customer_match_upload_key_type_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_customer__match__upload__key__type__pb2
from google.ads.google_ads.v0.proto.enums import user_list_crm_data_source_type_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_user__list__crm__data__source__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/common/user_lists.proto',
  package='google.ads.googleads.v0.common',
  syntax='proto3',
  serialized_pb=_b('\n5google/ads/googleads_v0/proto/common/user_lists.proto\x12\x1egoogle.ads.googleads.v0.common\x1aHgoogle/ads/googleads_v0/proto/enums/customer_match_upload_key_type.proto\x1aHgoogle/ads/googleads_v0/proto/enums/user_list_crm_data_source_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\"K\n\x13SimilarUserListInfo\x12\x34\n\x0eseed_user_list\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xa9\x02\n\x14\x43rmBasedUserListInfo\x12,\n\x06\x61pp_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12q\n\x0fupload_key_type\x18\x02 \x01(\x0e\x32X.google.ads.googleads.v0.enums.CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType\x12p\n\x10\x64\x61ta_source_type\x18\x03 \x01(\x0e\x32V.google.ads.googleads.v0.enums.UserListCrmDataSourceTypeEnum.UserListCrmDataSourceTypeB\xc4\x01\n\"com.google.ads.googleads.v0.commonB\x0eUserListsProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V0.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V0\\Commonb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_customer__match__upload__key__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_user__list__crm__data__source__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_SIMILARUSERLISTINFO = _descriptor.Descriptor(
  name='SimilarUserListInfo',
  full_name='google.ads.googleads.v0.common.SimilarUserListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seed_user_list', full_name='google.ads.googleads.v0.common.SimilarUserListInfo.seed_user_list', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=269,
  serialized_end=344,
)


_CRMBASEDUSERLISTINFO = _descriptor.Descriptor(
  name='CrmBasedUserListInfo',
  full_name='google.ads.googleads.v0.common.CrmBasedUserListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='google.ads.googleads.v0.common.CrmBasedUserListInfo.app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upload_key_type', full_name='google.ads.googleads.v0.common.CrmBasedUserListInfo.upload_key_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_source_type', full_name='google.ads.googleads.v0.common.CrmBasedUserListInfo.data_source_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=644,
)

_SIMILARUSERLISTINFO.fields_by_name['seed_user_list'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CRMBASEDUSERLISTINFO.fields_by_name['app_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CRMBASEDUSERLISTINFO.fields_by_name['upload_key_type'].enum_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_customer__match__upload__key__type__pb2._CUSTOMERMATCHUPLOADKEYTYPEENUM_CUSTOMERMATCHUPLOADKEYTYPE
_CRMBASEDUSERLISTINFO.fields_by_name['data_source_type'].enum_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_user__list__crm__data__source__type__pb2._USERLISTCRMDATASOURCETYPEENUM_USERLISTCRMDATASOURCETYPE
DESCRIPTOR.message_types_by_name['SimilarUserListInfo'] = _SIMILARUSERLISTINFO
DESCRIPTOR.message_types_by_name['CrmBasedUserListInfo'] = _CRMBASEDUSERLISTINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SimilarUserListInfo = _reflection.GeneratedProtocolMessageType('SimilarUserListInfo', (_message.Message,), dict(
  DESCRIPTOR = _SIMILARUSERLISTINFO,
  __module__ = 'google.ads.google_ads.v0.proto.common.user_lists_pb2'
  ,
  __doc__ = """SimilarUserList is a list of users which are similar to users from
  another UserList. These lists are read-only and automatically created by
  Google.
  
  
  Attributes:
      seed_user_list:
          Seed UserList from which this list is derived.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.common.SimilarUserListInfo)
  ))
_sym_db.RegisterMessage(SimilarUserListInfo)

CrmBasedUserListInfo = _reflection.GeneratedProtocolMessageType('CrmBasedUserListInfo', (_message.Message,), dict(
  DESCRIPTOR = _CRMBASEDUSERLISTINFO,
  __module__ = 'google.ads.google_ads.v0.proto.common.user_lists_pb2'
  ,
  __doc__ = """UserList of CRM users provided by the advertiser.
  
  
  Attributes:
      app_id:
          A string that uniquely identifies a mobile application from
          which the data was collected to the Google Ads API. For iOS,
          the ID string is the 9 digit string that appears at the end of
          an App Store URL (e.g., "476943146" for "Flood-It! 2" whose
          App Store link is http://itunes.apple.com/us/app/flood-
          it!-2/id476943146). For Android, the ID string is the
          application's package name (e.g., "com.labpixies.colordrips"
          for "Color Drips" given Google Play link https://play.google.c
          om/store/apps/details?id=com.labpixies.colordrips). Required
          when creating CrmBasedUserList for uploading mobile
          advertising IDs.
      upload_key_type:
          Matching key type of the list. Mixed data types are not
          allowed on the same list. This field is required for an ADD
          operation.
      data_source_type:
          Data source of the list. Default value is FIRST\_PARTY. Only
          whitelisted customers can create third party sourced crm
          lists.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.common.CrmBasedUserListInfo)
  ))
_sym_db.RegisterMessage(CrmBasedUserListInfo)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\"com.google.ads.googleads.v0.commonB\016UserListsProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V0.Common\312\002\036Google\\Ads\\GoogleAds\\V0\\Common'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/hotel_group_view_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import hotel_group_view_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_hotel__group__view__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/hotel_group_view_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nEgoogle/ads/googleads_v0/proto/services/hotel_group_view_service.proto\x12 google.ads.googleads.v0.services\x1a>google/ads/googleads_v0/proto/resources/hotel_group_view.proto\x1a\x1cgoogle/api/annotations.proto\"1\n\x18GetHotelGroupViewRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xd7\x01\n\x15HotelGroupViewService\x12\xbd\x01\n\x11GetHotelGroupView\x12:.google.ads.googleads.v0.services.GetHotelGroupViewRequest\x1a\x31.google.ads.googleads.v0.resources.HotelGroupView\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/v0/{resource_name=customers/*/hotelGroupViews/*}B\xda\x01\n$com.google.ads.googleads.v0.servicesB\x1aHotelGroupViewServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_hotel__group__view__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_GETHOTELGROUPVIEWREQUEST = _descriptor.Descriptor(
  name='GetHotelGroupViewRequest',
  full_name='google.ads.googleads.v0.services.GetHotelGroupViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetHotelGroupViewRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=250,
)

DESCRIPTOR.message_types_by_name['GetHotelGroupViewRequest'] = _GETHOTELGROUPVIEWREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetHotelGroupViewRequest = _reflection.GeneratedProtocolMessageType('GetHotelGroupViewRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETHOTELGROUPVIEWREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.hotel_group_view_service_pb2'
  ,
  __doc__ = """Request message for
  [HotelGroupViewService.GetHotelGroupView][google.ads.googleads.v0.services.HotelGroupViewService.GetHotelGroupView].
  
  
  Attributes:
      resource_name:
          Resource name of the Hotel Group View to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetHotelGroupViewRequest)
  ))
_sym_db.RegisterMessage(GetHotelGroupViewRequest)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\032HotelGroupViewServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_HOTELGROUPVIEWSERVICE = _descriptor.ServiceDescriptor(
  name='HotelGroupViewService',
  full_name='google.ads.googleads.v0.services.HotelGroupViewService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=253,
  serialized_end=468,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetHotelGroupView',
    full_name='google.ads.googleads.v0.services.HotelGroupViewService.GetHotelGroupView',
    index=0,
    containing_service=None,
    input_type=_GETHOTELGROUPVIEWREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_hotel__group__view__pb2._HOTELGROUPVIEW,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0023\0221/v0/{resource_name=customers/*/hotelGroupViews/*}')),
  ),
])
_sym_db.RegisterServiceDescriptor(_HOTELGROUPVIEWSERVICE)

DESCRIPTOR.services_by_name['HotelGroupViewService'] = _HOTELGROUPVIEWSERVICE

# @@protoc_insertion_point(module_scope)
